.. IoT-UPnP documentation master file, created by
   sphinx-quickstart on Thu Sep  6 13:51:40 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to IoT-UPnP's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
.. automodule:: upnp
      :members: Annoncer, Device, Service


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
